All pastes #553822 Raw Edit

Stuff

public text v1 · immutable
·published 2007-06-09 22:09 UTC
rendered paste body
$ fink install docbook-dtd
Information about 2608 packages read in 1 seconds.
The following package will be installed or updated:
 docbook-dtd
Setting runtime build-lock...
dpkg-deb -b /sw/src/fink.build/root-fink-buildlock-docbook-dtd-4.5.0-1 /sw/src/fink.build
dpkg-deb: building package `fink-buildlock-docbook-dtd-4.5.0-1' in `/sw/src/fink.build/fink-buildlock-docbook-dtd-4.5.0-1_2007.06.09-15.08.41_darwin-powerpc.deb'.
Installing build-lock package...
/sw/bin/dpkg-lockwait -i /sw/src/fink.build/fink-buildlock-docbook-dtd-4.5.0-1_2007.06.09-15.08.41_darwin-powerpc.deb
Selecting previously deselected package fink-buildlock-docbook-dtd-4.5.0-1.
(Reading database ... 11211 files and directories currently installed.)
Unpacking fink-buildlock-docbook-dtd-4.5.0-1 (from .../fink-buildlock-docbook-dtd-4.5.0-1_2007.06.09-15.08.41_darwin-powerpc.deb) ...
Setting up fink-buildlock-docbook-dtd-4.5.0-1 (2007.06.09-15.08.41) ...
unzip -o /sw/src/docbk10.zip
Archive:  /sw/src/docbk10.zip
  inflating: docbook.dtd             
unzip -o /sw/src/docbk11.zip
Archive:  /sw/src/docbk11.zip
  inflating: docbook.dtd             
unzip -o /sw/src/docbk12.zip
Archive:  /sw/src/docbk12.zip
  inflating: ch03.sgm                
  inflating: docbook1.0.dtd          
  inflating: docbook1.2.doc.sgml     
  inflating: docbook1.2.dtd          
  inflating: README                  
  inflating: sgml.declaration        
  inflating: xlsc.sgm                
unzip -o /sw/src/docbk121.zip
Archive:  /sw/src/docbk121.zip
  inflating: docbook1.2.1.doc.sgml   
  inflating: docbook1.2.1.dtd        
  inflating: ORAents.v3m             
  inflating: README                  
  inflating: sgml.declaration        
  inflating: xlsc.sgm                
unzip -o /sw/src/docbk21.zip
Archive:  /sw/src/docbk21.zip
 extracting: almfullguide.sgm.Z      
  inflating: alph.guide.sgm          
  inflating: docbook.2.1.dtd         
  inflating: sgml.declaration        
unzip -o /sw/src/docbk221.zip
Archive:  /sw/src/docbk221.zip
  inflating: docbook.2.2.1.dtd       
  inflating: docbook.dcl             
  inflating: iso-amsa.gml            
  inflating: iso-amsb.gml            
  inflating: iso-amsc.gml            
  inflating: iso-amsn.gml            
  inflating: iso-amso.gml            
  inflating: iso-amsr.gml            
  inflating: iso-box.gml             
  inflating: iso-cyr1.gml            
  inflating: iso-cyr2.gml            
  inflating: iso-dia.gml             
  inflating: iso-grk1.gml            
  inflating: iso-grk2.gml            
  inflating: iso-grk3.gml            
  inflating: iso-grk4.gml            
  inflating: iso-lat1.gml            
  inflating: iso-lat2.gml            
  inflating: iso-num.gml             
  inflating: iso-pub.gml             
  inflating: iso-tech.gml            
  inflating: isodia.ent              
  inflating: isomfrk.ent             
  inflating: isomopf.ent             
  inflating: isomscr.ent             
  inflating: msg.exm.sgm             
  inflating: README                  
unzip -o /sw/src/docbk23.zip
Archive:  /sw/src/docbk23.zip
  inflating: calstbl.mod             
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
  inflating: iso-amsa.gml            
  inflating: iso-amsb.gml            
  inflating: iso-amsc.gml            
  inflating: iso-amsn.gml            
  inflating: iso-amso.gml            
  inflating: iso-amsr.gml            
  inflating: iso-box.gml             
  inflating: iso-cyr1.gml            
  inflating: iso-cyr2.gml            
  inflating: iso-dia.gml             
  inflating: iso-grk1.gml            
  inflating: iso-grk2.gml            
  inflating: iso-grk3.gml            
  inflating: iso-grk4.gml            
  inflating: iso-lat1.gml            
  inflating: iso-lat2.gml            
  inflating: iso-num.gml             
  inflating: iso-pub.gml             
  inflating: iso-tech.gml            
  inflating: isodia.ent              
  inflating: isomfrk.ent             
  inflating: isomopf.ent             
  inflating: isomscr.ent             
  inflating: knownbugs23.html        
  inflating: README                  
unzip -o /sw/src/docbk24.zip
Archive:  /sw/src/docbk24.zip
  inflating: 24CHANGE.TXT            
  inflating: ANNOUNCE.TXT            
  inflating: CALSTBL.MOD             
  inflating: DBGENENT.MOD            
  inflating: DBHIER.MOD              
  inflating: DBPOOL.MOD              
  inflating: DOCBOOK.CAT             
  inflating: DOCBOOK.DTD             
unzip -o /sw/src/docbk241.zip
Archive:  /sw/src/docbk241.zip
  inflating: 241chg.txt              
  inflating: announce.txt            
  inflating: calstbl.mod             
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
  inflating: iso-amsa.gml            
  inflating: iso-amsb.gml            
  inflating: iso-amsc.gml            
  inflating: iso-amsn.gml            
  inflating: iso-amso.gml            
  inflating: iso-amsr.gml            
  inflating: iso-box.gml             
  inflating: iso-cyr1.gml            
  inflating: iso-cyr2.gml            
  inflating: iso-dia.gml             
  inflating: iso-grk1.gml            
  inflating: iso-grk2.gml            
  inflating: iso-grk3.gml            
  inflating: iso-grk4.gml            
  inflating: iso-lat1.gml            
  inflating: iso-lat2.gml            
  inflating: iso-num.gml             
  inflating: iso-pub.gml             
  inflating: iso-tech.gml            
unzip -o /sw/src/docbk30.zip
Archive:  /sw/src/docbk30.zip
  inflating: 30chg.txt               
  inflating: 40issues.txt            
  inflating: announce.txt            
  inflating: cals-tbl.dtd            
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
unzip -o /sw/src/docbk31.zip
Archive:  /sw/src/docbk31.zip
  inflating: 31chg.txt               
  inflating: 40issues.txt            
  inflating: 50issues.txt            
  inflating: cals-tbl.dtd            
  inflating: ChangeLog               
  inflating: dbcent.mod              
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbnotn.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
  inflating: readme.txt              
unzip -o /sw/src/docbk40.zip
Archive:  /sw/src/docbk40.zip
  inflating: 40chg.txt               
  inflating: 50issues.txt            
  inflating: cals-tbl.dtd            
  inflating: dbcent.mod              
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbnotn.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
  inflating: readme.txt              
unzip -o /sw/src/docbk41.zip
Archive:  /sw/src/docbk41.zip
  inflating: 40chg.txt               
  inflating: 50issues.txt            
  inflating: cals-tbl.dtd            
  inflating: dbcent.mod              
  inflating: dbgenent.mod            
  inflating: dbhier.mod              
  inflating: dbnotn.mod              
  inflating: dbpool.mod              
  inflating: docbook.cat             
  inflating: docbook.dcl             
  inflating: docbook.dtd             
  inflating: readme.txt              
  inflating: 41chg.txt               
  inflating: ChangeLog               
unzip -o /sw/src/docbkx40.zip
Archive:  /sw/src/docbkx40.zip
  inflating: calstblx.dtd            
  inflating: dbcentx.mod             
  inflating: dbgenent.ent            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbookx.dtd            
   creating: ent/
  inflating: readme.txt              
  inflating: soextblx.dtd            
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
  inflating: 40chg.txt               
unzip -o /sw/src/docbkx41.zip
Archive:  /sw/src/docbkx41.zip
  inflating: calstblx.dtd            
  inflating: dbcentx.mod             
  inflating: dbgenent.ent            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbookx.dtd            
   creating: ent/
  inflating: readme.txt              
  inflating: soextblx.dtd            
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
  inflating: 40chg.txt               
  inflating: 41chg.txt               
  inflating: ChangeLog               
  inflating: docbook.cat             
unzip -o /sw/src/docbkx411.zip
Archive:  /sw/src/docbkx411.zip
  inflating: calstblx.dtd            
  inflating: dbcentx.mod             
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbookx.dtd            
   creating: ent/
  inflating: readme.txt              
  inflating: soextblx.dtd            
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
  inflating: 40chg.txt               
  inflating: 41chg.txt               
  inflating: ChangeLog               
  inflating: docbook.cat             
  inflating: dbgenent.mod            
unzip -o /sw/src/docbkx412.zip
Archive:  /sw/src/docbkx412.zip
  inflating: calstblx.dtd            
  inflating: dbcentx.mod             
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbookx.dtd            
   creating: ent/
  inflating: readme.txt              
  inflating: soextblx.dtd            
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
  inflating: 40chg.txt               
  inflating: 41chg.txt               
  inflating: ChangeLog               
  inflating: docbook.cat             
  inflating: dbgenent.mod            
unzip -o /sw/src/docbook-xml-4.2.zip
Archive:  /sw/src/docbook-xml-4.2.zip
  inflating: README                  
  inflating: calstblx.dtd            
  inflating: catalog.xml             
  inflating: dbcentx.mod             
  inflating: dbgenent.mod            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbook.cat             
  inflating: docbookx.dtd            
  inflating: soextblx.dtd            
  inflating: ChangeLog               
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
unzip -o /sw/src/docbook-xml-4.3.zip
Archive:  /sw/src/docbook-xml-4.3.zip
  inflating: README                  
  inflating: calstblx.dtd            
  inflating: catalog.xml             
  inflating: dbcentx.mod             
  inflating: dbgenent.mod            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbook.cat             
  inflating: docbookx.dtd            
  inflating: soextblx.dtd            
  inflating: ChangeLog               
  inflating: ent/iso-amsa.ent        
  inflating: ent/iso-amsb.ent        
  inflating: ent/iso-amsc.ent        
  inflating: ent/iso-amsn.ent        
  inflating: ent/iso-amso.ent        
  inflating: ent/iso-amsr.ent        
  inflating: ent/iso-box.ent         
  inflating: ent/iso-cyr1.ent        
  inflating: ent/iso-cyr2.ent        
  inflating: ent/iso-dia.ent         
  inflating: ent/iso-grk1.ent        
  inflating: ent/iso-grk2.ent        
  inflating: ent/iso-grk3.ent        
  inflating: ent/iso-grk4.ent        
  inflating: ent/iso-lat1.ent        
  inflating: ent/iso-lat2.ent        
  inflating: ent/iso-num.ent         
  inflating: ent/iso-pub.ent         
  inflating: ent/iso-tech.ent        
  inflating: htmltblx.mod            
unzip -o /sw/src/docbook-xml-4.4.zip
Archive:  /sw/src/docbook-xml-4.4.zip
  inflating: README                  
  inflating: calstblx.dtd            
  inflating: catalog.xml             
  inflating: dbcentx.mod             
  inflating: dbgenent.mod            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbook.cat             
  inflating: docbookx.dtd            
  inflating: soextblx.dtd            
  inflating: ChangeLog               
  inflating: htmltblx.mod            
  inflating: ent/README              
  inflating: ent/isoamsa.ent         
  inflating: ent/isoamsb.ent         
  inflating: ent/isoamsc.ent         
  inflating: ent/isoamsn.ent         
  inflating: ent/isoamso.ent         
  inflating: ent/isoamsr.ent         
  inflating: ent/isobox.ent          
  inflating: ent/isocyr1.ent         
  inflating: ent/isocyr2.ent         
  inflating: ent/isodia.ent          
  inflating: ent/isogrk1.ent         
  inflating: ent/isogrk2.ent         
  inflating: ent/isogrk3.ent         
  inflating: ent/isogrk4.ent         
  inflating: ent/isolat1.ent         
  inflating: ent/isolat2.ent         
  inflating: ent/isonum.ent          
  inflating: ent/isopub.ent          
  inflating: ent/isotech.ent         
unzip -o /sw/src/docbook-xml-4.5.zip
Archive:  /sw/src/docbook-xml-4.5.zip
  inflating: calstblx.dtd            
  inflating: catalog.xml             
  inflating: dbcentx.mod             
  inflating: dbgenent.mod            
  inflating: dbhierx.mod             
  inflating: dbnotnx.mod             
  inflating: dbpoolx.mod             
  inflating: docbook.cat             
  inflating: docbookx.dtd            
  inflating: ent/README              
  inflating: ent/isoamsa.ent         
  inflating: ent/isoamsb.ent         
  inflating: ent/isoamsc.ent         
  inflating: ent/isoamsn.ent         
  inflating: ent/isoamso.ent         
  inflating: ent/isoamsr.ent         
  inflating: ent/isobox.ent          
  inflating: ent/isocyr1.ent         
  inflating: ent/isocyr2.ent         
  inflating: ent/isodia.ent          
  inflating: ent/isogrk1.ent         
  inflating: ent/isogrk2.ent         
  inflating: ent/isogrk3.ent         
  inflating: ent/isogrk4.ent         
  inflating: ent/isolat1.ent         
  inflating: ent/isolat2.ent         
  inflating: ent/isonum.ent          
  inflating: ent/isopub.ent          
  inflating: ent/isotech.ent         
  inflating: htmltblx.mod            
  inflating: README                  
  inflating: soextblx.dtd            
  inflating: ChangeLog               
sed 's|@PREFIX@|/sw|g' </sw/fink/dists/stable/main/finkinfo/text/docbook-dtd.patch | patch -p1
patching file sgml_catalog
patching file xml_catalog
/var/tmp/tmp.0.VXtlkq
#!/bin/sh -ev
echo "Preparing modell, changing system uri"
Preparing modell, changing system uri
for v in 4.0 4.1 4.1.1 4.1.2 4.2.0 4.3.0 4.4.0 4.5.0; do
  sed -e "s|@VERSION@|$v|g" <xml_catalog >docbook-dtd-$v-temp
done
echo "Changing public uri, adding modules for v>=4.4"
Changing public uri, adding modules for v>=4.4
for w in 4.0 4.1 4.1.1 4.1.2 4.2 4.3 4.4 4.5; do 
        if [ "$w" = "4.2" ] || [ "$w" = "4.3" ]; then
                sed -e "s|@VERSIONOASIS@|$w|g" \
                                        -e "/^BEGINFIRSTV4.4/,/^ENDFIRSTV4.4/d" \
                                        -e "/^BEGINSECONDV4.4/,/^ENDSECONDV4.4/d" <docbook-dtd-$w.0-temp >docbook-dtd-$w.0
                rm -f docbook-dtd-$w.0-temp*
        else
                if [ "$w" = "4.4" ] || [ "$w" = "4.5" ]; then
                        sed -e "s|@VERSIONOASIS@|$w|g" \
                                                -e "/^BEGINFIRSTV4.4/d" \
                                                -e "/^ENDFIRSTV4.4/d" \
                                                -e "/^BEGINSECONDV4.4/d" \
                                                -e "/^ENDSECONDV4.4/d" <docbook-dtd-$w.0-temp >docbook-dtd-$w.0
                        rm -f docbook-dtd-$w.0-temp*
                else
                        sed -e "s|@VERSIONOASIS@|$w|g" \
                                                -e "/^BEGINFIRSTV4.4/,/^ENDFIRSTV4.4/d" \
                                                -e "/^BEGINSECONDV4.4/,/^ENDSECONDV4.4/d" <docbook-dtd-$w-temp >docbook-dtd-$w
                        rm -f docbook-dtd-$w-temp*
                fi
  fi
done
/bin/rm -rf /sw/src/fink.build/root-docbook-dtd-4.5.0-1
/bin/mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw
/bin/mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/DEBIAN
/usr/sbin/chown -R root:admin /sw/src/fink.build/root-docbook-dtd-4.5.0-1
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx
touch /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "2.3/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "2.4/DOCBOOK.CAT"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "2.4.1/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "3.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "3.1/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "4.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
echo 'CATALOG "4.1/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/catalog
touch /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.1/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.1.1/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.1.2/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.2.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.3.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.4.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
echo 'CATALOG "4.5.0/docbook.cat"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/catalog
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/1.0
mv docbook.dtd /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/1.0
mv docbk11   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/1.1
mv docbk12   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/1.2
mv docbk121  /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/1.2.1
mv docbk21   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.1
mv docbk221  /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.2.1
mv docbk23   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.3
mv docbk24   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.4
mv docbk241  /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.4.1
mv docbk30   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/3.0
mv docbk31   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/3.1
mv docbk40   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/4.0
mv docbk41   /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/4.1
mv docbkx40  /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.0
mv docbkx41  /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.1
mv docbkx411 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.1.1
mv docbkx412 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.1.2
mv docbook-xml-4_2_0 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.2.0
mv docbook-xml-4_3_0 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.3.0
mv docbook-xml-4_4_0 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.4.0
mv docbook-xml-4_5_0 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.5.0
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.3
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/2.4.1
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/3.0
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/3.1
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/4.0
cp /sw/share/sgml/entities/iso8879/*.gml /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/sgml/dtd/docbook/4.1
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/etc/xml/catalog.d
cp docbook-dtd-* /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/etc/xml/catalog.d/
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/etc/sgml/catalog.d
cp sgml_catalog /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/etc/sgml/catalog.d/docbook
echo '"/sw/share/xml/dtd/docbookx/catalog"' >> /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/etc/sgml/catalog.d/docbook
mkdir -p /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/doc/docbook-dtd
head -n 30 /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/xml/dtd/docbookx/4.5.0/docbookx.dtd > /sw/src/fink.build/root-docbook-dtd-4.5.0-1/sw/share/doc/docbook-dtd/COPYRIGHT
Unknown option: n
Usage: head [-options] <url>...
    -m <method>   use method for the request (default is 'HEAD')
    -f            make request even if head believes method is illegal
    -b <base>     Use the specified URL as base
    -t <timeout>  Set timeout value
    -i <time>     Set the If-Modified-Since header on the request
    -c <conttype> use this content-type for POST, PUT, CHECKIN
    -a            Use text mode for content I/O
    -p <proxyurl> use this as a proxy
    -P            don't load proxy settings from environment
    -H <header>   send this HTTP header (you can specify several)

    -u            Display method and URL before any response
    -U            Display request headers (implies -u)
    -s            Display response status code
    -S            Display response status chain
    -e            Display response headers
    -d            Do not display content
    -o <format>   Process HTML content in various ways

    -v            Show program version
    -h            Print this message

    -x            Extra debugging output
### execution of head failed, exit code 255
Removing runtime build-lock...
Removing build-lock package...
/sw/bin/dpkg-lockwait -r fink-buildlock-docbook-dtd-4.5.0-1
(Reading database ... 11212 files and directories currently installed.)
Removing fink-buildlock-docbook-dtd-4.5.0-1 ...
Failed: phase installing: docbook-dtd-4.5.0-1 failed

Before reporting any errors, please run "fink selfupdate" and
try again.  If you continue to have issues, please check to see if the
FAQ on fink's website solves the problem.  If not, ask on the fink-users
or fink-beginners mailing lists.  As a last resort, you can try e-mailing
the maintainer directly:

        Michele Garoche <michele.garoche@easyconnect.fr>

Note that many fink package maintainers do not have access to all possible
hardware configurations, so you may have better luck on the mailing lists.


$